@@ -10,7 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import hashlib
 import os
+import re
 import ssl
 import sys
 
@@ -45,36 +47,8 @@ class viserver_open(object):
             raise exception.VIServerConnectionOpenError(vi=self.vi, error=e)
 
         return self.conn
-        # try:
-        #     if self.vi_username and self.vi_password:
-        #
-        #         def request_cred(credentials, user_data):
-        #             for credential in credentials:
-        #                 if credential[0] == libvirt.VIR_CRED_AUTHNAME:
-        #                     credential[4] = self.vi_username
-        #                 elif credential[0] == libvirt.VIR_CRED_PASSPHRASE:
-        #                     credential[4] = self.vi_password
-        #             return 0
-        #
-        #         auth = [
-        #             [libvirt.VIR_CRED_AUTHNAME, libvirt.VIR_CRED_PASSPHRASE],
-        #             request_cred,
-        #             None,
-        #         ]
-        #         flags = libvirt.VIR_CONNECT_RO if self.readonly else 0
-        #         self.conn = libvirt.openAuth(self.vi, auth, flags)
-        #     elif self.readonly:
-        #         self.conn = libvirt.openReadOnly(self.vi)
-        #     else:
-        #         self.conn = libvirt.open(self.vi)
-        #
-        #     return self.conn
-        #
-        # except libvirt.libvirtError as e:
-        #     raise exception.VIServerConnectionOpenError(vi=self.vi, error=e)
 
     def __exit__(self, type, value, traceback):
-        # self.conn.close()
         _ = Disconnect(self.conn)
 
 
@@ -158,6 +132,19 @@ def mask_dict_password(dictionary, secret="***"):
     return d
 
 
+def generate_fakemac_by_vm_name(vm_name):
+    hash = hashlib.md5(vm_name.encode()).digest()
+    fakemac = ":".join(
+        "%02x" % b for b in [0x02, 0x00, 0x00, hash[0], hash[1], hash[2]]
+    )
+    return fakemac
+
+
+def convert_fakemac_string_to_bytes(fakemac_str):
+    fakemac_bytes = [int(b, 16) for b in re.split(":|-", fakemac_str)]
+    return fakemac_bytes
+
+
 class detach_process(object):
     """Detach the process from its parent and session."""
 
